@@ -40,10 +40,7 @@ class ApiKeyTranslate:
     :param model: str: (可选) 翻译模型. 可以是 base 使用 Phrase-Based Machine Translation (PBMT) 模型，
         或者 nmt 使用 Neural Machine Translation (NMT) 模型。如果省略，则使用 nmt。如果模型是 nmt，
         并且 NMT 模型不支持请求的语言翻译对，则使用 PBMT 模型翻译请求。
-    :param proxies: (可选) eg: proxies = {
-            'http': 'http://localhost:10809',
-            'https': 'http://localhost:10809'
-        }
+    :param proxies: (可选) eg: `proxies = {'http': 'http://localhost:10809','https': 'http://localhost:10809'}`
 
     基本用法:
         >>> from pygtrans import ApiKeyTranslate
