@@ -10,4 +10,4 @@ class LanguageResponse:
         self.name = name
 
     def __repr__(self):
-        return self.__class__.__qualname__ + f'(language={self.language}, name={self.name})'
+        return self.__class__.__qualname__ + f'(language={repr(self.language)}, name={repr(self.language)})'
